==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/nl.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'nl', {
	button: {
		title: 'Eigenschappen knop',
		text: 'Tekst (waarde)',
		type: 'Soort',
		typeBtn: 'Knop',
		typeSbm: 'Versturen',
		typeRst: 'Leegmaken'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Eigenschappen aanvinkvakje',
		radioTitle: 'Eigenschappen selectievakje',
		value: 'Waarde',
		selected: 'Geselecteerd'
	},
	form: {
		title: 'Eigenschappen formulier',
		menu: 'Eigenschappen formulier',
		action: 'Actie',
		method: 'Methode',
		encoding: 'Codering'
	},
	hidden: {
		title: 'Eigenschappen verborgen veld',
		name: 'Naam',
		value: 'Waarde'
	},
	select: {
		title: 'Eigenschappen selectieveld',
		selectInfo: 'Informatie',
		opAvail: 'Beschikbare opties',
		value: 'Waarde',
		size: 'Grootte',
		lines: 'Regels',
		chkMulti: 'Gecombineerde selecties toestaan',
		opText: 'Tekst',
		opValue: 'Waarde',
		btnAdd: 'Toevoegen',
		btnModify: 'Wijzigen',
		btnUp: 'Omhoog',
		btnDown: 'Omlaag',
		btnSetValue: 'Als geselecteerde waarde instellen',
		btnDelete: 'Verwijderen'
	},
	textarea: {
		title: 'Eigenschappen tekstvak',
		cols: 'Kolommen',
		rows: 'Rijen'
	},
	textfield: {
		title: 'Eigenschappen tekstveld',
		name: 'Naam',
		value: 'Waarde',
		charWidth: 'Breedte (tekens)',
		maxChars: 'Maximum aantal tekens',
		type: 'Soort',
		typeText: 'Tekst',
		typePass: 'Wachtwoord',
		typeEmail: 'E-mail',
		typeSearch: 'Zoeken',
		typeTel: 'Telefoonnummer',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/nl.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'nl', {
	button: {
		title: 'Eigenschappen knop',
		text: 'Tekst (waarde)',
		type: 'Soort',
		typeBtn: 'Knop',
		typeSbm: 'Versturen',
		typeRst: 'Leegmaken'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Eigenschappen aanvinkvakje',
		radioTitle: 'Eigenschappen selectievakje',
		value: 'Waarde',
		selected: 'Geselecteerd',
		required: 'Vereist'
	},
	form: {
		title: 'Eigenschappen formulier',
		menu: 'Eigenschappen formulier',
		action: 'Actie',
		method: 'Methode',
		encoding: 'Codering'
	},
	hidden: {
		title: 'Eigenschappen verborgen veld',
		name: 'Naam',
		value: 'Waarde'
	},
	select: {
		title: 'Eigenschappen selectieveld',
		selectInfo: 'Informatie',
		opAvail: 'Beschikbare opties',
		value: 'Waarde',
		size: 'Grootte',
		lines: 'Regels',
		chkMulti: 'Gecombineerde selecties toestaan',
		required: 'Vereist',
		opText: 'Tekst',
		opValue: 'Waarde',
		btnAdd: 'Toevoegen',
		btnModify: 'Wijzigen',
		btnUp: 'Omhoog',
		btnDown: 'Omlaag',
		btnSetValue: 'Als geselecteerde waarde instellen',
		btnDelete: 'Verwijderen'
	},
	textarea: {
		title: 'Eigenschappen tekstvak',
		cols: 'Kolommen',
		rows: 'Rijen'
	},
	textfield: {
		title: 'Eigenschappen tekstveld',
		name: 'Naam',
		value: 'Waarde',
		charWidth: 'Breedte (tekens)',
		maxChars: 'Maximum aantal tekens',
		required: 'Vereist',
		type: 'Soort',
		typeText: 'Tekst',
		typePass: 'Wachtwoord',
		typeEmail: 'E-mail',
		typeSearch: 'Zoeken',
		typeTel: 'Telefoonnummer',
		typeUrl: 'URL'
	}
} );
